@@ -526,7 +526,7 @@ void InstrumentTemplate::read(XmlReader& e)
             channel.append(a);
             }
       if (useDrumset) {
-            if (channel[0].bank == 0 && channel[0].synti.toLower() != "zerberus")
+            if (channel[0].bank == 0 && channel[0].name != "Zerberus")
                   channel[0].bank = 128;
             channel[0].updateInitList();
             }
