@@ -296,7 +296,10 @@ void TextLineSegment::layout1()
       bbox().setRect(x1, y1, x2 - x1, y2 - y1);
       // set end text position and extend bbox
       if (_endText) {
-            _endText->setPos(bbox().right(), 0);
+            // Set _endText's position horizontally related to the dimensions of the previously formed rectangle.
+            // Previously, this was performed while 'zeroing' the vertical alignment, hence the bug of
+            // non-effect regarding the user-defined end-text's vertical alignment
+            _endText->setUserXoffset(bbox().right());
             bbox() |= _endText->bbox().translated(_endText->pos());
             }
       }
