@@ -221,16 +221,6 @@ void SynthControl::setMeter(float l, float r, float left_peak, float right_peak)
       gain->setMeterVal(1, r, right_peak);
       }
 
-//---------------------------------------------------------
-//   setScore
-//---------------------------------------------------------
-void SynthControl::setScore(Score* s) {
-      _score = s;
-
-      loadButton->setEnabled(true);
-      saveButton->setEnabled(true);
-      }
-
 //---------------------------------------------------------
 //   stop
 //---------------------------------------------------------
