@@ -126,9 +126,8 @@ void Voice::start(Channel* c, int key, int v, const Zone* zone, double durSinceN
       //    -> afterwards 0.5 (-6dB) is applied to compensate possible coherent
       //       signals in a stereo output see http://www.sengpielaudio.com/calculator-coherentsources.htm
       //    -> 0.005 = 0.01 * 0.5
-      gain        = (z->volume * z->group_volume * z->global_volume) * (offset + z->ampVeltrack * curve)
-                    * .005 * c->gain() * rt_decay_value *
-                    pow(10.0, 4.5 / 20.0); //attenuated volume between Fluid and Zerberus on 4.5dB
+      gain        = (z->volume * z->group_volume) * (offset + z->ampVeltrack * curve)
+                    * .005 * c->gain() * rt_decay_value;
 
       phase.set(0);
       float sr = float(s->sampleRate()) / _zerberus->sampleRate();
