@@ -17,14 +17,11 @@
 #include <atomic>
 // #include <mutex>
 #include <list>
-#include <memory>
-#include <queue>
 
 #include "synthesizer/synthesizer.h"
 #include "synthesizer/event.h"
 #include "voice.h"
 
-
 class Channel;
 class ZInstrument;
 enum class Trigger : char;
@@ -38,33 +35,32 @@ static const int MAX_TRIGGER = 512;
 //---------------------------------------------------------
 
 class VoiceFifo {
-      std::queue<Voice*> buffer;
-      std::vector< std::unique_ptr<Voice> > voices;
+      Voice* buffer[MAX_VOICES];
+      std::atomic<int> n;
+      int writeIdx = 0;       // index of next slot to write
+      int readIdx  = 0;       // index of slot to read
 
    public:
       VoiceFifo() {
-            voices.resize(MAX_VOICES);
+            n = 0;
             }
-
-      void init(Zerberus* z) {
-            for (int i = 0; i < MAX_VOICES; ++i) {
-                  voices.push_back(std::unique_ptr<Voice>(new Voice(z)));
-                  buffer.push(voices.back().get());
-                  }
+      ~VoiceFifo() {
+            for (Voice* v : buffer)
+                  delete v;
             }
-
       void push(Voice* v) {
-            buffer.push(v);
+            buffer[writeIdx++] = v;
+            writeIdx %= MAX_VOICES;
+            ++n;
             }
-    
-      Voice* pop() {
-            Q_ASSERT(!buffer.empty());
-            Voice* v = buffer.front();
-            buffer.pop();
+      Voice* pop()  {
+            Q_ASSERT(n != 0);
+            --n;
+            Voice* v = buffer[readIdx++];
+            readIdx %= MAX_VOICES;
             return v;
             }
-
-      bool empty() const { return buffer.empty(); }
+      bool empty() const { return n == 0; }
       };
 
 //---------------------------------------------------------
